@@ -4,9 +4,9 @@ use strum_macros::Display;
 
 #[derive(Copy, Clone, Debug, Display, Eq, PartialEq)]
 pub enum SerdeFormat {
-    #[cfg(feature = "serde_bincode")]
+    #[cfg(feature = "__serde_bincode")]
     Bincode,
-    #[cfg(feature = "serde_cbor")]
+    #[cfg(feature = "__serde_cbor")]
     Cbor,
 }
 
@@ -14,9 +14,9 @@ pub enum SerdeFormat {
 #[must_use]
 pub fn serde_format() -> SerdeFormat {
     let mut formats = vec![];
-    #[cfg(feature = "serde_bincode")]
+    #[cfg(feature = "__serde_bincode")]
     formats.push(SerdeFormat::Bincode);
-    #[cfg(feature = "serde_cbor")]
+    #[cfg(feature = "__serde_cbor")]
     formats.push(SerdeFormat::Cbor);
     assert!(
         formats.len() <= 1,
@@ -30,9 +30,9 @@ impl SerdeFormat {
     #[must_use]
     pub fn as_feature(self) -> &'static str {
         match self {
-            #[cfg(feature = "serde_bincode")]
+            #[cfg(feature = "__serde_bincode")]
             SerdeFormat::Bincode => "serde_bincode",
-            #[cfg(feature = "serde_cbor")]
+            #[cfg(feature = "__serde_cbor")]
             SerdeFormat::Cbor => "serde_cbor",
         }
     }
